@@ -33,6 +33,12 @@ typedef enum
 	DEV_ETEN_G500,
 	DEV_HW_SKEYEPADXSL,
 	DEV_N800,
+	DEV_AXIM_X5X,
+	DEV_PALM_TX,
+	DEV_GTA01,
+	DEV_NEON,
+	DEV_MAINSTONE,
+	DEV_N810,
 	DEV_MAX
 } DeviceID_t;
 
